==> eagle-i-model-jena-1.1-MS5.01-sources.jar: org/eaglei/model/jena/MetadataConstants.java <==
/**
 * The eagle-i consortium
 * Harvard University
 * Jul 9, 2010
 */
package org.eaglei.model.jena;

import java.util.HashMap;
import java.util.Map;

import org.eaglei.model.EIEntity;
import org.eaglei.model.EIURI;

/**
 * @author Daniela Bourges-Waldegg
 * 
 */
public class MetadataConstants {
	// read-onlymetadata; would be better to read from repository ontology
	// Use our own labels for now
	// datatools
	private static final EIURI sourceUri = EIURI.create( "http://eagle-i.org/ont/datatools/1.0/source" );
	private static final EIEntity sourceEntity = EIEntity.create( sourceUri, "ETL data source" );

	// workflow & repo
	private static final EIURI WFStateUri = EIURI.create( "http://eagle-i.org/ont/repo/1.0/hasWorkflowState" );
	private static final EIEntity WFStateEntity = EIEntity.create( WFStateUri, "Workflow state" );

	private static final EIURI WFOwnerUri = EIURI.create( "http://eagle-i.org/ont/repo/1.0/hasWorkflowOwner" );
	private static final EIEntity WFOwnerEntity = EIEntity.create( WFOwnerUri, "Workflow owner" );
	private static final EIURI editTokenUri = EIURI.create( "http://eagle-i.org/ont/repo/1.0/hasEditToken" );
	private static final EIEntity editTokenEntity = EIEntity.create( editTokenUri, "Edit token (repository internal)" );
	
	// dcterms
	private static final EIURI createdUri = EIURI.create( "http://purl.org/dc/terms/created" );
	private static final EIEntity createdEntity = EIEntity.create( createdUri, "Creation date" );

	private static final EIURI modifiedUri = EIURI.create( "http://purl.org/dc/terms/modified" );
	private static final EIEntity modifiedEntity = EIEntity.create( modifiedUri, "Last modification date" );

	private static final EIURI creatorUri = EIURI.create( "http://purl.org/dc/terms/creator" );
	private static final EIEntity creatorEntity = EIEntity.create( creatorUri, "Creator" );

	private static final EIURI mediatorUri = EIURI.create( "http://purl.org/dc/terms/mediator" );
	private static final EIEntity mediatorEntity = EIEntity.create( mediatorUri, "Mediator" );

	private static final EIURI contributorUri = EIURI.create( "http://purl.org/dc/terms/contributor" );
	private static final EIEntity contributorEntity = EIEntity.create( contributorUri, "Contributor" );

	public static final Map<EIURI, EIEntity> readOnlyResources = new HashMap<EIURI, EIEntity>();
	static {
		readOnlyResources.put( WFStateUri, WFStateEntity );
		readOnlyResources.put( WFOwnerUri, WFOwnerEntity );
		readOnlyResources.put( creatorUri, creatorEntity );
		readOnlyResources.put( mediatorUri, mediatorEntity );
		readOnlyResources.put( contributorUri, contributorEntity );
	}

	public static final Map<EIURI, EIEntity> readOnlyLiterals = new HashMap<EIURI, EIEntity>();
	static {
		readOnlyLiterals.put( sourceUri, sourceEntity );
		readOnlyLiterals.put( createdUri, createdEntity );
		readOnlyLiterals.put( modifiedUri, modifiedEntity );
		readOnlyLiterals.put( editTokenUri, editTokenEntity );
	}
	// Workspace constants
	public static final String WORKSPACE_NAMED_GRAPH_URI = "namedGraphURI";
	public static final String WORKSPACE_NAMED_GRAPH_LABEL = "namedGraphLabel";
	public static final String WORKSPACE_ADD = "add";
	public static final String WORKSPACE_REMOVE = "remove";
	public static final String WORKSPACE_TYPE = "typeURI";
}

==> eagle-i-model-jena-1.2-MS1.00-sources.jar: org/eaglei/model/jena/MetadataConstants.java <==
/**
 * The eagle-i consortium
 * Harvard University
 * Jul 9, 2010
 */
package org.eaglei.model.jena;

import java.util.HashMap;
import java.util.Map;

import org.eaglei.model.EIEntity;
import org.eaglei.model.EIURI;

/**
 * @author Daniela Bourges-Waldegg
 * 
 */
public class MetadataConstants {
	// read-onlymetadata; would be better to read from repository ontology
	// Use our own labels for now
	// datatools
	private static final EIURI sourceUri = EIURI.create( "http://eagle-i.org/ont/datatools/1.0/source" );
	private static final EIEntity sourceEntity = EIEntity.create( sourceUri, "ETL data source" );

	// workflow & repo
	private static final EIURI WFStateUri = EIURI.create( "http://eagle-i.org/ont/repo/1.0/hasWorkflowState" );
	private static final EIEntity WFStateEntity = EIEntity.create( WFStateUri, "Workflow state" );

	private static final EIURI WFOwnerUri = EIURI.create( "http://eagle-i.org/ont/repo/1.0/hasWorkflowOwner" );
	private static final EIEntity WFOwnerEntity = EIEntity.create( WFOwnerUri, "Workflow owner" );
	private static final EIURI editTokenUri = EIURI.create( "http://eagle-i.org/ont/repo/1.0/hasEditToken" );
	private static final EIEntity editTokenEntity = EIEntity.create( editTokenUri, "Edit token (repository internal)" );
	
	// dcterms
	private static final EIURI createdUri = EIURI.create( "http://purl.org/dc/terms/created" );
	private static final EIEntity createdEntity = EIEntity.create( createdUri, "Creation date" );

	private static final EIURI modifiedUri = EIURI.create( "http://purl.org/dc/terms/modified" );
	private static final EIEntity modifiedEntity = EIEntity.create( modifiedUri, "Last modification date" );

	private static final EIURI creatorUri = EIURI.create( "http://purl.org/dc/terms/creator" );
	private static final EIEntity creatorEntity = EIEntity.create( creatorUri, "Creator" );

	private static final EIURI mediatorUri = EIURI.create( "http://purl.org/dc/terms/mediator" );
	private static final EIEntity mediatorEntity = EIEntity.create( mediatorUri, "Mediator" );

	private static final EIURI contributorUri = EIURI.create( "http://purl.org/dc/terms/contributor" );
	private static final EIEntity contributorEntity = EIEntity.create( contributorUri, "Contributor" );

	public static final Map<EIURI, EIEntity> readOnlyResources = new HashMap<EIURI, EIEntity>();
	static {
		readOnlyResources.put( WFStateUri, WFStateEntity );
		readOnlyResources.put( WFOwnerUri, WFOwnerEntity );
		readOnlyResources.put( creatorUri, creatorEntity );
		readOnlyResources.put( mediatorUri, mediatorEntity );
		readOnlyResources.put( contributorUri, contributorEntity );
	}

	public static final Map<EIURI, EIEntity> readOnlyLiterals = new HashMap<EIURI, EIEntity>();
	static {
		readOnlyLiterals.put( sourceUri, sourceEntity );
		readOnlyLiterals.put( createdUri, createdEntity );
		readOnlyLiterals.put( modifiedUri, modifiedEntity );
		readOnlyLiterals.put( editTokenUri, editTokenEntity );
	}
	// Workspace constants
	public static final String WORKSPACE_NAMED_GRAPH_URI = "namedGraphURI";
	public static final String WORKSPACE_NAMED_GRAPH_LABEL = "namedGraphLabel";
	public static final String WORKSPACE_ADD = "add";
	public static final String WORKSPACE_REMOVE = "remove";
	public static final String WORKSPACE_TYPE = "typeURI";
	
	// Workflow
	//   URIs
	public static final String WITHDRAW_URI = "http://eagle-i.org/ont/repo/1.0/WFS_Withdrawn";
	public static final String PUBLISH_URI = "http://eagle-i.org/ont/repo/1.0/WFS_Published";
	public static final String CURATION_URI = "http://eagle-i.org/ont/repo/1.0/WFS_Curation";
	public static final String DRAFT_URI = "http://eagle-i.org/ont/repo/1.0/WFS_Draft";

	//   labels
	public static final String CURATION_STATE_LABEL = "In curation";
	public static final String PUBLISH_STATE_LABEL = "Published";
	public static final String DRAFT_STATE_LABEL = "Draft";
	public static final String WITHDRAW_STATE_LABEL = "Withdrawn";

	//   entities
	public static final EIEntity CURATION_ENTITY = EIEntity.create( CURATION_URI, CURATION_STATE_LABEL );
	public static final EIEntity PUBLISH_ENTITY = EIEntity.create( PUBLISH_URI, PUBLISH_STATE_LABEL );
	public static final EIEntity DRAFT_ENTITY = EIEntity.create( DRAFT_URI, DRAFT_STATE_LABEL );
	public static final EIEntity WITHDRAW_ENTITY = EIEntity.create( WITHDRAW_URI, WITHDRAW_STATE_LABEL );

	public static EIEntity getStatusEntity(final EIURI statusUri) {
		if ( statusUri == null ) {
			return EIEntity.NULL_ENTITY;
		}
		if ( DRAFT_URI.equals( statusUri.toString() ) ) {
			return DRAFT_ENTITY;
		} else if ( CURATION_URI.equals( statusUri.toString() ) ) {
			return CURATION_ENTITY;
		} else if ( PUBLISH_URI.equals( statusUri.toString() ) ) {
			return PUBLISH_ENTITY;
		} else if ( WITHDRAW_URI.equals( statusUri.toString() ) ) {
			return WITHDRAW_ENTITY;
		}
		return EIEntity.NULL_ENTITY;
	}

}
